@@ -702,25 +702,30 @@ class RenderSequencePlayblasts_XX(flow.Action):
             shot.submit(self.pool.get())
 
 
-class RenderSequencePlayblasts(flow.Action):
-    
-    ICON = ('icons.gui', 'film-strip-with-two-photograms')
-    
+class ProcessSequenceFiles(flow.Action):
+
     _sequence = flow.Parent()
-    
+
     def __init__(self, parent, name):
-        super(RenderSequencePlayblasts, self).__init__(parent, name)
-        self._shots_data = None
+        super(ProcessSequenceFiles, self).__init__(parent, name)
+        self._files_data = None
     
-    def ensure_shots_data(self):
-        if self._shots_data is None:
-            self._shots_data = self._compute_shots_data()
+    def ensure_files_data(self):
+        '''
+        Method used to cache computed files data
+        '''
+        if self._files_data is None:
+            self._files_data = self._compute_files_data()
         
-        return self._shots_data
+        return self._files_data
     
-    def get_job_pool_names(self):
-        site = self.root().project().get_current_site()
-        return ['default'] + site.pool_names.get()
+    def _compute_files_data(self):
+        '''
+        Computes data related to files contained in a sequence
+        '''
+        raise NotImplementedError(
+            'Subclasses must return shot files data'
+        )
     
     def get_shot_task_files(self, fnpattern):
         template = self.root().project().admin.dependency_templates['shot']
@@ -731,16 +736,16 @@ class RenderSequencePlayblasts(flow.Action):
         
         for dep_name in default_dep_names:
             dep = dependencies[dep_name]
-            file_departments = dict()
+            files = []
             
             for file_name, file_data in dep['files'].items():
                 if fnmatch(file_name, fnpattern):
-                    file_departments[file_name] = file_data['department']
+                    files.append((file_name, file_data))
             
-            if file_departments:
+            if files:
                 template_tasks_files.append((
                     dep_name,
-                    file_departments
+                    files
                 ))
         
         return template_tasks_files
@@ -748,6 +753,15 @@ class RenderSequencePlayblasts(flow.Action):
     def get_shot_task_names(self, fnpattern):
         task_files = self.get_shot_task_files(fnpattern)
         return [name for name, _ in task_files]
+
+
+class RenderSequencePlayblasts(ProcessSequenceFiles):
+    
+    ICON = ('icons.gui', 'film-strip-with-two-photograms')
+    
+    def get_job_pool_names(self):
+        site = self.root().project().get_current_site()
+        return ['default'] + site.pool_names.get()
     
     def submit_playblast_job(self, shot_name, dept_name, file_name, revision_name, use_simplify, priority=10, pool_name='default'):
         file_name = file_name.replace('.', '_')
@@ -760,34 +774,35 @@ class RenderSequencePlayblasts(flow.Action):
         file.submit_playblast_job.pool.set(pool_name)
         file.submit_playblast_job.run('Add to render pool')
     
-    def _compute_shots_data(self):
+    def _compute_files_data(self):
         # Keep only tasks which contain Blender files
-        template_tasks_files = self.get_shot_task_files('*.blend')
+        blender_files_by_task = self.get_shot_task_files('*.blend')
         
         shots = self._sequence.shots
-        shots_data = []
+        files_data = []
         
         for shot in shots.mapped_items():
             tasks_files = []
             
-            for task_files in template_tasks_files:
-                task_name = task_files[0]
-                task_file_departments = task_files[1].items()
-                
+            for task_name, task_files in blender_files_by_task:
                 files = []
                 
-                for file_name, file_dept in task_file_departments:
+                for file_name, file_data in task_files:
                     file_mapped_name = file_name.replace('.', '_')
-                    file_oid = f'{shot.oid()}/departments/{file_dept}/files/{file_mapped_name}'
+                    dept_name = file_data['department']
+                    file_oid = f'{shot.oid()}/departments/{dept_name}/files/{file_mapped_name}'
                     
                     if not self.root().session().cmds.Flow.exists(file_oid):
                         # Skip if file does not exist in the flow
                         continue
                     
                     file = self.root().get_object(file_oid)
-                    revision_names = file.get_revision_names(published_only=True)
+                    revision_statuses = file.get_revision_statuses(published_only=True)
+                    head = file.get_head_revision(sync_status='Available')
                     
-                    if not revision_names:
+                    default_revision = head.name() if head is not None else None
+                    
+                    if not revision_statuses:
                         self.root().session().log_warning(
                             f'File {file.oid()} has no published revision available'
                         )
@@ -797,8 +812,9 @@ class RenderSequencePlayblasts(flow.Action):
                         oid=file.oid(),
                         name=file_name,
                         shot=shot.name(),
-                        department=file_dept,
-                        revisions=revision_names
+                        department=dept_name,
+                        revisions=revision_statuses,
+                        default_revision=default_revision
                     ))
                 
                 tasks_files.append(dict(
@@ -806,13 +822,13 @@ class RenderSequencePlayblasts(flow.Action):
                     files=files
                 ))
             
-            shots_data.append(dict(
+            files_data.append(dict(
                 oid=shot.oid(),
                 name=shot.name(),
                 tasks=tasks_files
             ))
         
-        return shots_data
+        return files_data
     
     def _fill_ui(self, ui):
         ui['custom_page'] = 'libreflow.utils.ui.RenderSequencePlayblastsWidget'
