@@ -84,12 +84,15 @@ class EditFileRunner(Runner):
 
     def executable(self):
         exec_var = self.exec_env_var()
+
         if self.version:
             exec_var += "_%s" % self.version.replace(".", "_")
 
         try:
+            print('[RUNNER] exec path: ', os.environ[exec_var])
             return os.environ[exec_var]
         except KeyError:
+            print('[RUNNER] exec path: ', os.environ[self.exec_env_var()])
             return os.environ[self.exec_env_var()]
 
 
