@@ -66,6 +66,9 @@ class RenderWithAfterEffect(RunAction):
     def runner_name_and_tags(self):
         return "AfterEffectRender", []
 
+    def get_run_label(self):
+        return 'Render'
+
     @classmethod
     def supported_extensions(cls):
         return ["aep"]
