@@ -5,6 +5,8 @@ from kabaret.app.session import KabaretSession
 from kabaret.script_view import ScriptView
 from kabaret.subprocess_manager import SubprocessManager, LauncherToolBar
 
+from libreflow.utils.kabaret.jobs.jobs_node import JobsNodeSession
+
 
 class BaseGUISession(gui.KabaretStandaloneGUISession):
     def register_view_types(self):
@@ -31,3 +33,7 @@ class BaseCLISession(KabaretSession):
 
         # Configure SubprocessManager
         SubprocessManager(self)
+
+
+class JobsNodeSession(JobsNodeSession):
+    pass
\ No newline at end of file
