@@ -2,9 +2,10 @@ import sys
 import zipfile
 import sys
 import os
-
+import shutil
 from string import Formatter
 from collections import OrderedDict
+
 from kabaret.flow_contextual_dict import get_contextual_dict
 
 
@@ -79,8 +80,33 @@ def get_context_value(
     return context_value
 
 
-def zip_folder(folder_path, output_path):
+def remove_folder_content(folder_path):
+    '''
+    Deletes the content of a folder located at `folder_path`
+    without deleting the folder itself.
     
+    From https://stackoverflow.com/a/185941
+    '''
+    for file_name in os.listdir(folder_path):
+        file_path = os.path.join(folder_path, file_name)
+        try:
+            if os.path.isfile(file_path) or os.path.islink(file_path):
+                os.unlink(file_path)
+            else:
+                shutil.rmtree(file_path)
+        except Exception as e:
+            print(f'Failed to delete {folder_path} folder content.\n>>>\n{str(e)}')
+            return False
+    
+    return True
+
+
+def zip_folder(folder_path, output_path):
+    '''
+    Creates a ZIP archive with the content of the folder, located
+    at `folder_path`, at its root (i.e., it skips the folder level
+    itself in the resulting archive tree).
+    '''
     # Initialise empty file paths list
     file_paths = []
 
